@@ -30,14 +30,14 @@ class SftpCli(object):
                 If `--id=example`, the filesystem will be mounted to: `/mnt/sshfs/example`
             --host={host to connect to}
             --port={port to connect to} [default: 22]
-            --user={username to authenticate with} [default: current user]
+            --user={username to authenticate with}
             --mount_opt={option to pass to sshfs} [optional] [can be passed more than once]
                 Example: --mount_opt="follow_symlinks" --mount_opt="workaround=rename"
                 `sshfs --help` tells you what sshfs options are available
             --mount_point={remote path to mount}
             --auth_method={method}
                 Specifies the authentication method.
-                Can be `password` or `publickey`. [default: publickey]
+                Can be `password`, `publickey`, `hostbased`, `keyboard-interactive` or `gssapi-with-mic`. [default: publickey]
             --ssh_key={path to the ssh key to use for authentication}
                 Only applies if auth_method is `publickey`.
             --cmd_before_mount={command to run before mounting} [default: /bin/true]
@@ -69,11 +69,11 @@ class SftpCli(object):
         mount_opts = []
         for name, value in opts:
             name = name.lstrip('-')
-            if not hasattr(system, name):
-                continue
             if name == 'mount_opt':
                 mount_opts.append(value)
                 continue
+            if not hasattr(system, name):
+                continue
             setattr(system, name, value)
         system.mount_opts = mount_opts
 
@@ -81,7 +81,7 @@ class SftpCli(object):
         if not is_valid:
             sys.stderr.write('Invalid data found:\n')
             for field_name, msg in errors:
-                sys.stderr.write(' - %s / %s\n' % (field_name, msg))
+                sys.stderr.write(' - %s: %s\n' % (field_name, msg))
             sys.stderr.write('\n')
             usage()
             sys.exit(1)
@@ -125,9 +125,9 @@ class SftpCli(object):
                 sys.stderr.write(' - %s\n' % msg)
             sys.exit(1)
 
-    def command_ls(self, list_what):
+    def command_ls(self, list_what = 'available'):
         """Lists the available/mounted/unmounted sftp systems.
-        Usage: sftpman ls {what}
+        Usage: sftpman ls {what} [default: available]
         Where {what} is one of: available, mounted, unmounted
         """
         if list_what in ('available', 'mounted', 'unmounted'):
@@ -160,9 +160,9 @@ class SftpCli(object):
         if has_failed:
             sys.exit(1)
 
-    def command_unmount(self, system_id, *system_ids):
+    def command_umount(self, system_id, *system_ids):
         """Unmounts the specified sftp system.
-        Usage: sftpman unmount {id}..
+        Usage: sftpman umount {id}..
         """
         system_ids = (system_id,) + system_ids
         has_failed = False
@@ -196,9 +196,9 @@ class SftpCli(object):
                 sys.stderr.write('Command output: \n%s\n\n' % e.mount_cmd_output)
         sys.exit(0 if not has_failed else 1)
 
-    def command_unmount_all(self):
+    def command_umount_all(self):
         """Unmounts all sftp file systems known to sftpman.
-        Usage: sftpman unmount_all
+        Usage: sftpman umount_all
         """
         has_failed = False
         for system_id in self.environment.get_mounted_ids():
