@@ -18,7 +18,7 @@ class EnvironmentModel(object):
         self.config_path_mounts = '%smounts/' % self.config_path_base
 
     def get_system_config_path(self, system_id):
-        return '%s%s.js' % (self.config_path_mounts, system_id)
+        return '%s%s.json' % (self.config_path_mounts, system_id)
 
     def get_system_mount_dest(self, system_id):
         """The local path where the system will be mounted."""
@@ -43,7 +43,7 @@ class EnvironmentModel(object):
         if not os.path.exists(self.config_path_mounts):
             return []
         cfg_files = shell_exec('ls %s' % self.config_path_mounts).strip().split('\n')
-        return [file_name[0:-3] for file_name in cfg_files if file_name.endswith('.js')]
+        return [file_name[0:-5] for file_name in cfg_files if file_name.endswith('.json')]
 
     def get_mounted_ids(self):
         # Looking for /mnt/sshfs/{id} in output that looks like this:
@@ -87,6 +87,20 @@ class SystemModel(object):
 
     AUTH_METHOD_PUBLIC_KEY = 'publickey'
     AUTH_METHOD_PASSWORD = 'password'
+    AUTH_METHOD_INTERACTIVE = 'keyboard-interactive'
+    AUTH_METHOD_HOSTBASED = 'hostbased'
+    AUTH_METHOD_GSSAPI_WITH_MIC = 'gssapi-with-mic'
+
+    AUTH_METHODS = (
+        AUTH_METHOD_PUBLIC_KEY,
+        AUTH_METHOD_PASSWORD,
+        AUTH_METHOD_INTERACTIVE,
+        AUTH_METHOD_HOSTBASED,
+        AUTH_METHOD_GSSAPI_WITH_MIC
+    )
+
+    # libfuse (>=3.0.0) dropped support for big_writes
+    UNSUPPORTED_MOUNT_OPTS = ['big_writes']
 
     def __init__(self, **kwargs):
         self.id = kwargs.get('id', None)
@@ -94,6 +108,7 @@ class SystemModel(object):
         self.port = kwargs.get('port', SystemModel.SSH_PORT_DEFAULT)
         self.user = kwargs.get('user', None)
         self.mount_opts = list(kwargs.get('mountOptions', []))
+        self.mount_opts = [v for v in self.mount_opts if v not in SystemModel.UNSUPPORTED_MOUNT_OPTS]
         self.mount_point = kwargs.get('mountPoint', None)
         self.auth_method = kwargs.get('authType', self.AUTH_METHOD_PUBLIC_KEY)
         self.ssh_key = kwargs.get('sshKey', None)
@@ -112,32 +127,44 @@ class SystemModel(object):
     ssh_key = property(lambda self: self._ssh_key, _set_ssh_key)
 
     def validate(self):
+        def is_valid_id(value):
+            if value is None:
+                return False
+            if value in ('.', '..'):
+                return False
+            return re.compile('^[a-zA-Z0-9\.\-_@]+$').match(value) is not None
+
         def is_alphanumeric(value):
             if value is None:
                 return False
             # Well, not really alphanumeric, but close enough to call it that
             return re.compile('^[a-zA-Z0-9\.\-]+$').match(value) is not None
 
+        def is_valid_username(value):
+            if value is None:
+                return False
+            return re.compile('^[a-zA-Z0-9\.\-_\@]+$').match(value) is not None
+
         def is_valid_path(value):
             if value is None:
                 return False
             return re.compile('^/(([a-zA-Z0-9\.\-_]+)/?)*?$').match(value) is not None
 
         errors = []
-        if not is_alphanumeric(self.id):
-            errors.append(('id', 'IDs can only contain letters, digits, dot and dash.'))
+        if not is_valid_id(self.id):
+            errors.append(('id', 'IDs can only contain letters, digits, dot, @, dash and underscore.'))
         if not is_alphanumeric(self.host):
             errors.append(('host', 'Hosts can only contain letters, digits, dot and dash.'))
         if not is_valid_path(self.mount_point):
             errors.append(('mount_point', 'Invalid remote mount point.'))
-        if self.auth_method not in (self.AUTH_METHOD_PUBLIC_KEY, self.AUTH_METHOD_PASSWORD):
+        if self.auth_method not in self.AUTH_METHODS:
             errors.append(('auth_method', 'Unknown auth type.'))
         else:
             if self.auth_method == self.AUTH_METHOD_PUBLIC_KEY:
-                if not os.path.exists(self.ssh_key):
+                if self.ssh_key is None or not os.path.exists(self.ssh_key):
                     errors.append(('ssh_key', 'Invalid ssh key path.'))
-        if not is_alphanumeric(self.user):
-            errors.append(('user', 'Usernames can only contain letters and digits.'))
+        if not is_valid_username(self.user):
+            errors.append(('user', 'Usernames can only contain letters, at signs and digits.'))
         if not(self.PORT_RANGE_MIN < self.port <= self.PORT_RANGE_MAX):
             msg = 'Ports need to be numbers between %d and %d.' % (
                 self.PORT_RANGE_MIN,
@@ -163,7 +190,7 @@ class SystemModel(object):
         out['beforeMount'] = self.cmd_before_mount
         out['authType'] = self.auth_method
         out['sshKey'] = self.ssh_key
-        return json.dumps(out)
+        return json.dumps(out, indent=4)
 
     def save(self, environment):
         path = environment.get_system_config_path(self.id)
@@ -247,6 +274,8 @@ class SystemControllerModel(object):
 
         if self.system.auth_method == self.system.AUTH_METHOD_PUBLIC_KEY:
             ssh_opts = '-o PreferredAuthentications=publickey -i %s' % self.system.ssh_key
+        elif self.system.auth_method:
+            ssh_opts = '-o PreferredAuthentications=%s' % self.system.auth_method
         else:
             ssh_opts = '-o PreferredAuthentications=password'
 
